@@ -1,33 +1,19 @@
 /*
- *  This file is part of the KDE libraries
- *  Copyright (C) 2003 Benjamin C Meyer (ben+kdelibs at meyerhome dot net)
- *  Copyright (C) 2003 Waldo Bastian <bastian@kde.org>
- *  Copyright (C) 2004 Michael Brade <brade@kde.org>
- *
- *  Forked from KConfigDialog from KF5::ConfigWidgets to add tree support.
- *  Copyright (C) 2014 Eike Hein
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    SPDX-License-Identifier: LGPL-2.0-or-later
+
+    SPDX-FileCopyrightText: 2003 Benjamin C Meyer (ben+kdelibs at meyerhome dot net)
+    SPDX-FileCopyrightText: 2003 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2004 Michael Brade <brade@kde.org>
+
+    Forked from KConfigDialog from KF5::ConfigWidgets to add tree support.
+    SPDX-FileCopyrightText: 2014 Eike Hein
+*/
 #include "configdialog.h"
 
-#include <kconfigdialogmanager.h>
-#include <kcoreconfigskeleton.h>
-#include <kpagewidgetmodel.h>
-#include <khelpclient.h>
+#include <KConfigDialogManager>
+#include <KCoreConfigSkeleton>
+#include <KPageWidgetModel>
+#include <KHelpClient>
 
 #include <QApplication>
 #include <QDesktopWidget>
@@ -35,16 +21,18 @@
 #include <QIcon>
 #include <QLayout>
 #include <QPushButton>
-#include <QtCore/QMap>
+#include <QMap>
 #include <QCoreApplication>
 #include <QDesktopServices>
 #include <QScrollArea>
 
+#include <algorithm>
+
 class ConfigDialog::ConfigDialogPrivate
 {
 public:
     ConfigDialogPrivate(ConfigDialog *q, const QString &name, KCoreConfigSkeleton *config)
-        : q(q), shown(false), manager(0)
+        : q(q), shown(false), manager(nullptr)
     {
         q->setObjectName(name);
         q->setWindowTitle(tr("Configure"));
@@ -53,8 +41,7 @@ public:
         if (!name.isEmpty()) {
             openDialogs.insert(name, q);
         } else {
-            QString genericName;
-            genericName.sprintf("SettingsDialog-%p", static_cast<void *>(q));
+            const QString genericName = QString::asprintf("SettingsDialog-%p", static_cast<void *>(q));
             openDialogs.insert(genericName, q);
             q->setObjectName(genericName);
         }
@@ -65,15 +52,17 @@ public:
                                       | QDialogButtonBox::Apply
                                       | QDialogButtonBox::Cancel
                                       | QDialogButtonBox::Help);
-        connect(buttonBox->button(QDialogButtonBox::Ok), SIGNAL(clicked()), q, SLOT(updateSettings()));
-        connect(buttonBox->button(QDialogButtonBox::Apply), SIGNAL(clicked()), q, SLOT(updateSettings()));
-        connect(buttonBox->button(QDialogButtonBox::Apply), SIGNAL(clicked()), q, SLOT(_k_updateButtons()));
-        connect(buttonBox->button(QDialogButtonBox::Cancel), SIGNAL(clicked()), q, SLOT(updateWidgets()));
-        connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), SIGNAL(clicked()), q, SLOT(updateWidgetsDefault()));
-        connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), SIGNAL(clicked()), q, SLOT(_k_updateButtons()));
-        connect(buttonBox->button(QDialogButtonBox::Help), SIGNAL(clicked()), q, SLOT(showHelp()));
+        connect(buttonBox->button(QDialogButtonBox::Ok), &QAbstractButton::clicked, q, &ConfigDialog::updateSettings);
+        connect(buttonBox->button(QDialogButtonBox::Apply), &QAbstractButton::clicked, q, &ConfigDialog::updateSettings);
+        connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked,
+                q, [this]() { _k_updateButtons(); });
+        connect(buttonBox->button(QDialogButtonBox::Cancel), &QAbstractButton::clicked, q, &ConfigDialog::updateWidgets);
+        connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QAbstractButton::clicked, q, &ConfigDialog::updateWidgetsDefault);
+        connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked,
+                q, [this]() { _k_updateButtons(); });
+        connect(buttonBox->button(QDialogButtonBox::Help), &QAbstractButton::clicked, q, &ConfigDialog::showHelp);
 
-        connect(q, SIGNAL(pageRemoved(KPageWidgetItem*)), q, SLOT(onPageRemoved(KPageWidgetItem*)));
+        connect(q, &KPageDialog::pageRemoved, q, &ConfigDialog::onPageRemoved);
 
         manager = new KConfigDialogManager(q, config);
         setupManagerConnections(manager);
@@ -127,10 +116,10 @@ KPageWidgetItem *ConfigDialog::addPage(QWidget *page,
 {
     Q_ASSERT(page);
     if (!page) {
-        return 0;
+        return nullptr;
     }
 
-    KPageWidgetItem *item = d->addPageInternal(0, page, itemName, pixmapName, header);
+    KPageWidgetItem *item = d->addPageInternal(nullptr, page, itemName, pixmapName, header);
     if (manage) {
         d->manager->addWidget(page);
     }
@@ -155,12 +144,12 @@ KPageWidgetItem *ConfigDialog::konviAddSubPage(KPageWidgetItem *parent,
 {
     Q_ASSERT(parent);
     if (!parent) {
-        return 0;
+        return nullptr;
     }
 
     Q_ASSERT(page);
     if (!page) {
-        return 0;
+        return nullptr;
     }
 
     KPageWidgetItem *item = d->addPageInternal(parent, page, itemName, pixmapName, header);
@@ -187,10 +176,10 @@ KPageWidgetItem *ConfigDialog::addPage(QWidget *page,
 {
     Q_ASSERT(page);
     if (!page) {
-        return 0;
+        return nullptr;
     }
 
-    KPageWidgetItem *item = d->addPageInternal(0, page, itemName, pixmapName, header);
+    KPageWidgetItem *item = d->addPageInternal(nullptr, page, itemName, pixmapName, header);
     d->managerForPage[page] = new KConfigDialogManager(page, config);
     d->setupManagerConnections(d->managerForPage[page]);
 
@@ -213,7 +202,7 @@ KPageWidgetItem *ConfigDialog::ConfigDialogPrivate::addPageInternal(KPageWidgetI
 {
     QWidget *frame = new QWidget(q);
     QVBoxLayout *boxLayout = new QVBoxLayout(frame);
-    boxLayout->setMargin(0);
+    boxLayout->setContentsMargins(0, 0, 0, 0);
 
     QScrollArea *scroll = new QScrollArea(q);
     scroll->setFrameShape(QFrame::NoFrame);
@@ -241,14 +230,16 @@ KPageWidgetItem *ConfigDialog::ConfigDialogPrivate::addPageInternal(KPageWidgetI
 
 void ConfigDialog::ConfigDialogPrivate::setupManagerConnections(KConfigDialogManager *manager)
 {
-    q->connect(manager, SIGNAL(settingsChanged()), q, SLOT(_k_settingsChangedSlot()));
-    q->connect(manager, SIGNAL(widgetModified()), q, SLOT(_k_updateButtons()));
+    ConfigDialog::connect(manager, QOverload<>::of(&KConfigDialogManager::settingsChanged),
+                          q, [this]() { _k_settingsChangedSlot(); });
+    ConfigDialog::connect(manager, &KConfigDialogManager::widgetModified,
+                          q, [this]() { _k_updateButtons(); });
 
     QDialogButtonBox *buttonBox = q->buttonBox();
-    q->connect(buttonBox->button(QDialogButtonBox::Ok), &QPushButton::clicked, manager, &KConfigDialogManager::updateSettings);
-    q->connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, manager, &KConfigDialogManager::updateSettings);
-    q->connect(buttonBox->button(QDialogButtonBox::Cancel), &QPushButton::clicked, manager, &KConfigDialogManager::updateWidgets);
-    q->connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, manager, &KConfigDialogManager::updateWidgetsDefault);
+    ConfigDialog::connect(buttonBox->button(QDialogButtonBox::Ok), &QPushButton::clicked, manager, &KConfigDialogManager::updateSettings);
+    ConfigDialog::connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, manager, &KConfigDialogManager::updateSettings);
+    ConfigDialog::connect(buttonBox->button(QDialogButtonBox::Cancel), &QPushButton::clicked, manager, &KConfigDialogManager::updateWidgets);
+    ConfigDialog::connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, manager, &KConfigDialogManager::updateWidgetsDefault);
 }
 
 void ConfigDialog::ConfigDialogPrivate::setApplyButtonEnabled(bool enabled)
@@ -289,7 +280,7 @@ ConfigDialog *ConfigDialog::exists(const QString &name)
     if (it != ConfigDialogPrivate::openDialogs.constEnd()) {
         return *it;
     }
-    return 0;
+    return nullptr;
 }
 
 bool ConfigDialog::showDialog(const QString &name)
@@ -298,7 +289,7 @@ bool ConfigDialog::showDialog(const QString &name)
     if (dialog) {
         dialog->show();
     }
-    return (dialog != NULL);
+    return (dialog != nullptr);
 }
 
 void ConfigDialog::ConfigDialogPrivate::_k_updateButtons()
@@ -309,23 +300,15 @@ void ConfigDialog::ConfigDialogPrivate::_k_updateButtons()
     }
     only_once = true;
 
-    QMap<QWidget *, KConfigDialogManager *>::iterator it;
-
-    bool has_changed = manager->hasChanged() || q->hasChanged();
-    for (it = managerForPage.begin();
-            it != managerForPage.end() && !has_changed;
-            ++it) {
-        has_changed |= (*it)->hasChanged();
-    }
+    const bool has_changed = manager->hasChanged() || q->hasChanged() ||
+            std::any_of(managerForPage.cbegin(), managerForPage.cend(),
+                        [](KConfigDialogManager* manager) { return manager->hasChanged(); });
 
     setApplyButtonEnabled(has_changed);
 
-    bool is_default = manager->isDefault() && q->isDefault();
-    for (it = managerForPage.begin();
-            it != managerForPage.end() && is_default;
-            ++it) {
-        is_default &= (*it)->isDefault();
-    }
+    const bool is_default = manager->isDefault() && q->isDefault() &&
+            std::all_of(managerForPage.cbegin(), managerForPage.cend(),
+                        [](KConfigDialogManager* manager) { return manager->isDefault(); });
 
     setRestoreDefaultsButtonEnabled(!is_default);
 
@@ -343,29 +326,21 @@ void ConfigDialog::ConfigDialogPrivate::_k_settingsChangedSlot()
 void ConfigDialog::showEvent(QShowEvent *e)
 {
     if (!d->shown) {
-        QMap<QWidget *, KConfigDialogManager *>::iterator it;
-
         updateWidgets();
         d->manager->updateWidgets();
-        for (it = d->managerForPage.begin(); it != d->managerForPage.end(); ++it) {
-            (*it)->updateWidgets();
+        for (KConfigDialogManager* manager : qAsConst(d->managerForPage)) {
+            manager->updateWidgets();
         }
 
-        bool has_changed = d->manager->hasChanged() || hasChanged();
-        for (it = d->managerForPage.begin();
-                it != d->managerForPage.end() && !has_changed;
-                ++it) {
-            has_changed |= (*it)->hasChanged();
-        }
+        const bool has_changed = d->manager->hasChanged() || hasChanged() ||
+            std::any_of(d->managerForPage.cbegin(), d->managerForPage.cend(),
+                        [](KConfigDialogManager* manager) { return manager->hasChanged(); });
 
         d->setApplyButtonEnabled(has_changed);
 
-        bool is_default = d->manager->isDefault() && isDefault();
-        for (it = d->managerForPage.begin();
-                it != d->managerForPage.end() && is_default;
-                ++it) {
-            is_default &= (*it)->isDefault();
-        }
+        const bool is_default = d->manager->isDefault() && isDefault() &&
+            std::all_of(d->managerForPage.cbegin(), d->managerForPage.cend(),
+                        [](KConfigDialogManager* manager) { return manager->isDefault(); });
 
         d->setRestoreDefaultsButtonEnabled(!is_default);
 
