@@ -1,16 +1,12 @@
 /*
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
-  Copyright (C) 2006 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2006 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2006 Eike Hein <hein@kde.org>
 */
 
 #include "settingsdialog.h"
+
 #include "preferences.h"
 #include "ui_chatwindowappearance_config.h"
 #include "connectionbehavior_config.h"
@@ -32,47 +28,47 @@
 #include "ignore_config.h"
 #include "ui_watchednicknames_configui.h"
 #include "ui_tabnotifications_config.h"
+#include "konversation_log.h"
 
 #include <config-konversation.h>
 
-#include <KConfigDialog>
 #include <QIcon>
 #include <KLocalizedString>
 
 
 KonviSettingsDialog::KonviSettingsDialog( QWidget *parent) :
-    ConfigDialog( parent, QLatin1String("settings"), Preferences::self())
+    ConfigDialog( parent, QStringLiteral("settings"), Preferences::self())
 {
   setFaceType(KPageDialog::Tree);
 
   m_modified = false;
 
   KPageWidgetItem* interfaceGroup = new KPageWidgetItem(new QWidget(this), i18n("Interface"));
-  interfaceGroup->setIcon(QIcon::fromTheme("preferences-desktop-theme"));
+  interfaceGroup->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-theme")));
   KPageDialog::addPage(interfaceGroup);
 
   KPageWidgetItem* behaviorGroup = new KPageWidgetItem(new QWidget(this), i18n("Behavior"));
-  behaviorGroup->setIcon(QIcon::fromTheme("configure"));
+  behaviorGroup->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
   KPageDialog::addPage(behaviorGroup);
 
   KPageWidgetItem* notificationGroup = new KPageWidgetItem(new QWidget(this), i18n("Notifications"));
-  notificationGroup->setIcon(QIcon::fromTheme("preferences-desktop-notification"));
+  notificationGroup->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-notification")));
   KPageDialog::addPage(notificationGroup);
 
-  QWidget *w = 0;
+  QWidget *w = nullptr;
 
   //Interface/Chat Window
   Ui::ChatWindowAppearance_Config confChatWindowAppearance;
   w = new QWidget();
   confChatWindowAppearance.setupUi(w);
-  confChatWindowAppearance.kcfg_TimestampFormat->addItem("hh:mm");
-  confChatWindowAppearance.kcfg_TimestampFormat->addItem("hh:mm:ss");
-  confChatWindowAppearance.kcfg_TimestampFormat->addItem("h:m ap");
-  konviAddSubPage(interfaceGroup, w, i18n("Chat Window"), QLatin1String("view-list-text"));
+  confChatWindowAppearance.kcfg_TimestampFormat->addItem(QStringLiteral("hh:mm"));
+  confChatWindowAppearance.kcfg_TimestampFormat->addItem(QStringLiteral("hh:mm:ss"));
+  confChatWindowAppearance.kcfg_TimestampFormat->addItem(QStringLiteral("h:m ap"));
+  konviAddSubPage(interfaceGroup, w, i18n("Chat Window"), QStringLiteral("view-list-text"));
 
   //Interface/Themes
   m_confThemeWdg = new Theme_Config( this, "Theme" );
-  konviAddSubPage(interfaceGroup, m_confThemeWdg, i18n("Nicklist Themes"), QLatin1String("preferences-desktop-icons"));
+  konviAddSubPage(interfaceGroup, m_confThemeWdg, i18n("Nicklist Themes"), QStringLiteral("preferences-desktop-icons"));
   m_pages.append(m_confThemeWdg);
   connect(m_confThemeWdg, &Theme_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
 
@@ -80,34 +76,34 @@ KonviSettingsDialog::KonviSettingsDialog( QWidget *parent) :
   Ui::ColorsAppearance_Config confColorsAppearance;
   w = new QWidget();
   confColorsAppearance.setupUi(w);
-  konviAddSubPage(interfaceGroup, w, i18n("Colors"), QLatin1String("preferences-desktop-color"));
+  konviAddSubPage(interfaceGroup, w, i18n("Colors"), QStringLiteral("preferences-desktop-color"));
 
   //Interface/Fonts
   Ui::FontAppearance_Config confFontAppearance;
   w = new QWidget();
   confFontAppearance.setupUi(w);
-  konviAddSubPage(interfaceGroup, w, i18n("Fonts"), QLatin1String("preferences-desktop-font"));
+  konviAddSubPage(interfaceGroup, w, i18n("Fonts"), QStringLiteral("preferences-desktop-font"));
 
   //Interface/Quick Buttons
   m_confQuickButtonsWdg = new QuickButtons_Config( this, "QuickButtons" );
-  konviAddSubPage(interfaceGroup, m_confQuickButtonsWdg, i18n("Quick Buttons"), QLatin1String("preferences-desktop-keyboard"));
+  konviAddSubPage(interfaceGroup, m_confQuickButtonsWdg, i18n("Quick Buttons"), QStringLiteral("preferences-desktop-keyboard"));
   m_pages.append(m_confQuickButtonsWdg);
   connect(m_confQuickButtonsWdg, &QuickButtons_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
 
   //Interface/Tabs
   m_confTabBarWdg = new Tabs_Config( this, "TabBar" );
-  konviAddSubPage(interfaceGroup, m_confTabBarWdg, i18n("Tabs"), QLatin1String("tab-new"));
+  konviAddSubPage(interfaceGroup, m_confTabBarWdg, i18n("Tabs"), QStringLiteral("tab-new"));
 
   //Behavior/General
   Ui::GeneralBehavior_ConfigUI confGeneralBehavior;
   w = new QWidget();
   confGeneralBehavior.setupUi(w);
-  konviAddSubPage(behaviorGroup, w, i18n("General Behavior"), QLatin1String("configure"));
+  konviAddSubPage(behaviorGroup, w, i18n("General Behavior"), QStringLiteral("configure"));
 
   //Behavior/Connection
   ConnectionBehavior_Config* confConnectionBehavior = new ConnectionBehavior_Config(this);
-  confConnectionBehavior->setObjectName("ConnectionBehavior");
-  konviAddSubPage(behaviorGroup, confConnectionBehavior, i18n("Connection"), QLatin1String("network-connect"));
+  confConnectionBehavior->setObjectName(QStringLiteral("ConnectionBehavior"));
+  konviAddSubPage(behaviorGroup, confConnectionBehavior, i18n("Connection"), QStringLiteral("network-connect"));
   m_pages.append(confConnectionBehavior);
 
   //Behaviour/Chat Window
@@ -117,29 +113,29 @@ KonviSettingsDialog::KonviSettingsDialog( QWidget *parent) :
   confChatwindowBehaviour.kcfg_ScrollbackMax->setSuffix(ki18np(" line", " lines"));
   confChatwindowBehaviour.kcfg_AutoWhoNicksLimit->setSuffix(ki18np(" nick", " nicks"));
   confChatwindowBehaviour.kcfg_AutoWhoContinuousInterval->setSuffix(ki18np(" second", " seconds"));
-  konviAddSubPage(behaviorGroup, w, i18n("Chat Window"), QLatin1String("view-list-text"));
+  konviAddSubPage(behaviorGroup, w, i18n("Chat Window"), QStringLiteral("view-list-text"));
 
   //Behaviour/Nickname List
   m_confNicklistBehaviorWdg = new NicklistBehavior_Config( this, "NicklistBehavior" );
-  konviAddSubPage(behaviorGroup, m_confNicklistBehaviorWdg, i18n("Nickname List"), QLatin1String("preferences-contact-list"));
+  konviAddSubPage(behaviorGroup, m_confNicklistBehaviorWdg, i18n("Nickname List"), QStringLiteral("preferences-contact-list"));
   connect(m_confNicklistBehaviorWdg, &NicklistBehavior_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
   m_pages.append(m_confNicklistBehaviorWdg);
 
   //Behaviour/Command Aliases
   m_confAliasWdg = new Alias_Config( this, "Alias" );
-  konviAddSubPage(behaviorGroup, m_confAliasWdg, i18n("Command Aliases"), QLatin1String("edit-rename"));
+  konviAddSubPage(behaviorGroup, m_confAliasWdg, i18n("Command Aliases"), QStringLiteral("edit-rename"));
   m_pages.append(m_confAliasWdg);
   connect(m_confAliasWdg, &Alias_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
 
   //Behaviour/Auto Replace
   m_confAutoreplaceWdg = new Autoreplace_Config( this, "Autoreplace" );
-  konviAddSubPage(behaviorGroup, m_confAutoreplaceWdg, i18n("Auto Replace"), QLatin1String("edit-rename"));
+  konviAddSubPage(behaviorGroup, m_confAutoreplaceWdg, i18n("Auto Replace"), QStringLiteral("edit-rename"));
   m_pages.append(m_confAutoreplaceWdg);
   connect(m_confAutoreplaceWdg, &Autoreplace_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
 
   //Behaviour/Ignore
   m_confIgnoreWdg = new Ignore_Config(this, "Ignore");
-  konviAddSubPage(behaviorGroup, m_confIgnoreWdg, i18nc("@title:tab", "Ignore"), QLatin1String("process-stop"));
+  konviAddSubPage(behaviorGroup, m_confIgnoreWdg, i18nc("@title:tab", "Ignore"), QStringLiteral("process-stop"));
   connect(m_confIgnoreWdg, &Ignore_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
   m_pages.append(m_confIgnoreWdg);
 
@@ -148,21 +144,21 @@ KonviSettingsDialog::KonviSettingsDialog( QWidget *parent) :
   w = new QWidget();
   confLog.setupUi(w);
   confLog.kcfg_LogfilePath->setMode(KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly);
-  konviAddSubPage(behaviorGroup, w, i18n("Logging"), QLatin1String("text-plain"));
+  konviAddSubPage(behaviorGroup, w, i18n("Logging"), QStringLiteral("text-plain"));
 
   //DCC
   m_confDCCWdg = new DCC_Config(this, "DCC");
-  konviAddSubPage(behaviorGroup, m_confDCCWdg, i18nc("@title:tab", "DCC"), QLatin1String("arrow-right-double"));
+  konviAddSubPage(behaviorGroup, m_confDCCWdg, i18nc("@title:tab", "DCC"), QStringLiteral("arrow-right-double"));
 
   //Notifications/Tab Bar
   Ui::TabNotifications_Config confTabNotifications;
   w = new QWidget();
   confTabNotifications.setupUi(w);
-  konviAddSubPage(notificationGroup, w, i18n("Tabs"), QLatin1String("tab-new"));
+  konviAddSubPage(notificationGroup, w, i18n("Tabs"), QStringLiteral("tab-new"));
 
   //Notification/Highlighting
-  m_confHighlightWdg = new Highlight_Config( this, "Highlight" );
-  konviAddSubPage(notificationGroup, m_confHighlightWdg, i18n("Highlight"), QLatin1String("flag-red"));
+  m_confHighlightWdg = new Highlight_Config(this, QStringLiteral("Highlight"));
+  konviAddSubPage(notificationGroup, m_confHighlightWdg, i18n("Highlight"), QStringLiteral("flag-red"));
   connect(m_confHighlightWdg, &Highlight_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
   m_pages.append(m_confHighlightWdg);
 
@@ -170,17 +166,17 @@ KonviSettingsDialog::KonviSettingsDialog( QWidget *parent) :
   Ui::WatchedNicknames_ConfigUI confWatchedNicks;
   w = new QWidget();
   confWatchedNicks.setupUi(w);
-  konviAddSubPage(notificationGroup, w, i18n("Watched Nicknames"), QLatin1String("edit-find-user"));
+  konviAddSubPage(notificationGroup, w, i18n("Watched Nicknames"), QStringLiteral("edit-find-user"));
 
   //Notification/On Screen Display
   m_confOSDWdg = new OSD_Config( this, "OSD" );
-  konviAddSubPage(notificationGroup, m_confOSDWdg, i18n("On Screen Display"), QLatin1String("video-display"));
+  konviAddSubPage(notificationGroup, m_confOSDWdg, i18n("On Screen Display"), QStringLiteral("video-display"));
   //no modified connection needed - it's all kcfg widgets
   m_pages.append(m_confOSDWdg);
 
   //Notification/Warning Dialogs
   m_confWarningsWdg = new Warnings_Config( this, "Warnings" );
-  konviAddSubPage(notificationGroup, m_confWarningsWdg, i18n("Warning Dialogs"), QLatin1String("dialog-warning"));
+  konviAddSubPage(notificationGroup, m_confWarningsWdg, i18n("Warning Dialogs"), QStringLiteral("dialog-warning"));
   m_pages.append(m_confWarningsWdg);
   connect(m_confWarningsWdg, &Warnings_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
 }
@@ -189,14 +185,13 @@ void KonviSettingsDialog::modifiedSlot()
 {
   // this is for the non KConfigXT parts to tell us, if the user actually changed
   // something or went back to the old settings
-// qDebug();
+// qCDebug(KONVERSATION_LOG) << __FUNCTION__;
   m_modified = false;
-  foreach (KonviSettingsPage *page, m_pages)
-  {
+  for (KonviSettingsPage *page : qAsConst(m_pages)) {
     if (page->hasChanged())
     {
       m_modified = true;
-//      qDebug() << "modified!";
+//      qCDebug(KONVERSATION_LOG) << "modified!";
       break;
     }
   }
@@ -209,19 +204,17 @@ KonviSettingsDialog::~KonviSettingsDialog()
 
 void KonviSettingsDialog::updateSettings()
 {
-  foreach (KonviSettingsPage *page, m_pages)
-  {
+  for (KonviSettingsPage *page : qAsConst(m_pages)) {
     // this is for the non KConfigXT parts to update the UI (like quick buttons)
     page->saveSettings();
   }
   m_modified = false;
-  emit settingsChanged(QLatin1String("settings"));
+  emit settingsChanged(QStringLiteral("settings"));
 }
 
 void KonviSettingsDialog::updateWidgets()
 {
-  foreach (KonviSettingsPage *page, m_pages)
-  {
+  for (KonviSettingsPage *page : qAsConst(m_pages)) {
     page->loadSettings();
   }
   m_modified = false;
@@ -229,8 +222,7 @@ void KonviSettingsDialog::updateWidgets()
 
 void KonviSettingsDialog::updateWidgetsDefault()
 {
-  foreach (KonviSettingsPage *page, m_pages)
-  {
+  for (KonviSettingsPage *page : qAsConst(m_pages)) {
     page->restorePageToDefaults();
   }
   m_modified = true;
