@@ -1,23 +1,14 @@
 /*
-  receive a file on DCC protocol
-  begin:     Mit Aug 7 2002
-  copyright: (C) 2002 by Dario Abatianni
-  email:     eisfuchs@tigress.com
-*/
-/*
-  Copyright (C) 2004-2007 Shintaro Matsuoka <shin@shoegazed.org>
-  Copyright (C) 2004,2005 John Tapsell <john@geola.co.uk>
-  Copyright (C) 2009 Michael Kreitzer <mrgrim@gr1m.org>
-  Copyright (C) 2009 Bernd Buschinski <b.buschinski@web.de>
-*/
-/*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-License-Identifier: GPL-2.0-or-later
+
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2004-2007 Shintaro Matsuoka <shin@shoegazed.org>
+    SPDX-FileCopyrightText: 2004, 2005 John Tapsell <john@geola.co.uk>
+    SPDX-FileCopyrightText: 2009 Michael Kreitzer <mrgrim@gr1m.org>
+    SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
 */
 
-#include <qglobal.h>
+#include <QtGlobal>
 
 #ifdef Q_OS_WIN
 // Prevent windows system header files from defining min/max as macros.
@@ -32,6 +23,7 @@
 #include "connectionmanager.h"
 #include "server.h"
 #include "upnprouter.h"
+#include "konversation_log.h"
 
 #include <QDateTime>
 #include <QTcpSocket>
@@ -66,11 +58,11 @@ namespace Konversation
         TransferRecv::TransferRecv(QObject *parent)
             : Transfer(Transfer::Receive, parent)
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
-            m_serverSocket = 0;
-            m_recvSocket = 0;
-            m_writeCacheHandler = 0;
+            m_serverSocket = nullptr;
+            m_recvSocket = nullptr;
+            m_writeCacheHandler = nullptr;
 
             m_connectionTimer = new QTimer(this);
             m_connectionTimer->setSingleShot(true);
@@ -80,22 +72,22 @@ namespace Konversation
 
         TransferRecv::~TransferRecv()
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             cleanUp();
         }
 
         void TransferRecv::cleanUp()
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
             stopConnectionTimer();
-            disconnect(m_connectionTimer, 0, 0, 0);
+            disconnect(m_connectionTimer, nullptr, nullptr, nullptr);
 
             finishTransferLogger();
             if (m_serverSocket)
             {
                 m_serverSocket->close();
-                m_serverSocket = 0;
+                m_serverSocket = nullptr;
 
                 if (m_reverse && Preferences::self()->dccUPnP())
                 {
@@ -108,15 +100,15 @@ namespace Konversation
             }
             if (m_recvSocket)
             {
-                disconnect(m_recvSocket, 0, 0, 0);
+                disconnect(m_recvSocket, nullptr, nullptr, nullptr);
                 m_recvSocket->close();
-                m_recvSocket = 0;                         // the instance will be deleted automatically by its parent
+                m_recvSocket = nullptr;                         // the instance will be deleted automatically by its parent
             }
             if (m_writeCacheHandler)
             {
                 m_writeCacheHandler->closeNow();
                 m_writeCacheHandler->deleteLater();
-                m_writeCacheHandler = 0;
+                m_writeCacheHandler = nullptr;
             }
             Transfer::cleanUp();
         }
@@ -178,7 +170,7 @@ namespace Konversation
 
         bool TransferRecv::queue()
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
             if (getStatus() != Configuring)
             {
@@ -195,7 +187,7 @@ namespace Konversation
                 m_ownIp = DccCommon::getOwnIp(Application::instance()->getConnectionManager()->getServerByConnectionId(m_connectionId));
             }
 
-            if (!KAuthorized::authorizeAction("allow_downloading"))
+            if (!KAuthorized::authorizeAction(QStringLiteral("allow_downloading")))
             {
                 //note we have this after the initialisations so that item looks okay
                 //Do not have the rights to send the file.  Shouldn't have gotten this far anyway
@@ -204,7 +196,7 @@ namespace Konversation
             }
 
             // check if the sender IP is valid
-            if (m_partnerIp == "0.0.0.0")
+            if (m_partnerIp == QLatin1String("0.0.0.0"))
             {
                 failed(i18n("Invalid sender address (%1)", m_partnerIp));
                 return false;
@@ -219,7 +211,7 @@ namespace Konversation
 
             if (m_fileName.isEmpty())
             {
-                m_fileName = "unnamed_file_" + QDateTime::currentDateTime().toString(Qt::ISODate).remove(':');
+                m_fileName = QLatin1String("unnamed_file_") + QDateTime::currentDateTime().toString(Qt::ISODate).remove(QLatin1Char(':'));
                 m_saveFileName = m_fileName;
             }
 
@@ -255,7 +247,7 @@ namespace Konversation
                 if (Preferences::self()->dccAddPartner())
                 {
                     m_fileURL = m_fileURL.adjusted(QUrl::StripTrailingSlash);
-                    m_fileURL.setPath(m_fileURL.path() + QDir::separator() + m_partnerNick + '.' + fileNameSanitized);
+                    m_fileURL.setPath(m_fileURL.path() + QDir::separator() + m_partnerNick + QLatin1Char('.') + fileNameSanitized);
                 }
                 else
                 {
@@ -269,7 +261,7 @@ namespace Konversation
 
         void TransferRecv::abort()                     // public slot
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
             if (getStatus() == Transfer::Queued)
             {
@@ -292,7 +284,7 @@ namespace Konversation
 
         void TransferRecv::start()                     // public slot
         {
-            qDebug() << "[BEGIN]";
+            qCDebug(KONVERSATION_LOG) << "[BEGIN]";
 
             if (getStatus() != Queued)
             {
@@ -303,15 +295,15 @@ namespace Konversation
 
             prepareLocalKio(false, false);
 
-            qDebug() << "[END]";
+            qCDebug(KONVERSATION_LOG) << "[END]";
         }
 
         void TransferRecv::prepareLocalKio(bool overwrite, bool resume, KIO::fileoffset_t startPosition)
         {
-            qDebug()
-                << "URL: " << m_fileURL << endl
-                << "Overwrite: " << overwrite << endl
-                << "Resume: " << resume << " (Position: " << startPosition << ")";
+            qCDebug(KONVERSATION_LOG)
+                << "URL: " << m_fileURL
+                << "\nOverwrite: " << overwrite
+                << "\nResume: " << resume << " (Position: " << startPosition << ")";
 
             m_resumed = resume;
             m_transferringPosition = startPosition;
@@ -351,7 +343,7 @@ namespace Konversation
 
             if (!transferJob)
             {
-                qDebug() << "KIO::put() returned NULL. what happened?";
+                qCDebug(KONVERSATION_LOG) << "KIO::put() returned NULL. what happened?";
                 failed(i18n("Could not create a KIO instance"));
                 return;
             }
@@ -397,14 +389,12 @@ namespace Konversation
 
             //Now we create the directories
 
-            QList<QUrl>::ConstIterator it;
-            for (it=dirList.constBegin(); it != dirList.constEnd(); ++it)
-            {
-                KIO::StatJob* statJob = KIO::stat(*it, KIO::StatJob::SourceSide, 0);
+            for (const QUrl& dir : qAsConst(dirList)) {
+                KIO::StatJob* statJob = KIO::statDetails(dir, KIO::StatJob::SourceSide, KIO::StatNoDetails);
                 statJob->exec();
                 if (statJob->error())
                 {
-                    KIO::MkdirJob* job = KIO::mkdir(*it, -1);
+                    KIO::MkdirJob* job = KIO::mkdir(dir, -1);
                     if (!job->exec())
                     {
                         return false;
@@ -433,19 +423,19 @@ namespace Konversation
 
         void TransferRecv::slotLocalCanResume(KIO::Job *job, KIO::filesize_t size)
         {
-            qDebug() << "[BEGIN]" << endl
+            qCDebug(KONVERSATION_LOG) << "[BEGIN]\n"
                 << "size: " << size;
 
-            KIO::TransferJob* transferJob = dynamic_cast<KIO::TransferJob*>(job);
+            auto* transferJob = qobject_cast<KIO::TransferJob*>(job);
             if (!transferJob)
             {
-                qDebug() << "not a TransferJob? returning";
+                qCDebug(KONVERSATION_LOG) << "not a TransferJob? returning";
                 return;
             }
 
             if (size != 0)
             {
-                disconnect(transferJob, 0, 0, 0);
+                disconnect(transferJob, nullptr, nullptr, nullptr);
                 if (Preferences::self()->dccAutoResume())
                 {
                     prepareLocalKio(false, true, size);
@@ -468,20 +458,20 @@ namespace Konversation
                 transferJob->putOnHold();
             }
 
-            qDebug() << "[END]";
+            qCDebug(KONVERSATION_LOG) << "[END]";
         }
 
         void TransferRecv::slotLocalGotResult(KJob *job)
         {
-            qDebug() << "[BEGIN]";
+            qCDebug(KONVERSATION_LOG) << "[BEGIN]";
 
-            KIO::TransferJob* transferJob = static_cast<KIO::TransferJob*>(job);
-            disconnect(transferJob, 0, 0, 0);
+            auto* transferJob = static_cast<KIO::TransferJob*>(job);
+            disconnect(transferJob, nullptr, nullptr, nullptr);
 
             switch (transferJob->error())
             {
                 case 0:                                   // no error
-                    qDebug() << "job->error() returned 0." << endl
+                    qCDebug(KONVERSATION_LOG) << "job->error() returned 0.\n"
                         << "Why was I called in spite of no error?";
                     break;
                 case KIO::ERR_FILE_ALREADY_EXIST:
@@ -504,16 +494,16 @@ namespace Konversation
                         ResumeDialog::RA_Rename);
             }
 
-            qDebug() << "[END]";
+            qCDebug(KONVERSATION_LOG) << "[END]";
         }
 
         void TransferRecv::slotLocalReady(KIO::Job *job)
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
-            KIO::TransferJob* transferJob = static_cast<KIO::TransferJob*>(job);
+            auto* transferJob = static_cast<KIO::TransferJob*>(job);
 
-            disconnect(transferJob, 0, 0, 0);           // WriteCacheHandler will control the job after this
+            disconnect(transferJob, nullptr, nullptr, nullptr);           // WriteCacheHandler will control the job after this
 
             m_writeCacheHandler = new TransferRecvWriteCacheHandler(transferJob);
 
@@ -582,13 +572,14 @@ namespace Konversation
                 return;
             }
 
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
             if (Preferences::self()->dccUPnP() && this->sender())
             {
                 if (port != m_ownPort) return; // Somebody elses forward succeeded
 
-                disconnect (this->sender(), SIGNAL(forwardComplete(bool,quint16)), this, SLOT(sendReverseAck(bool,quint16)));
+                auto* router = qobject_cast<UPnP::UPnPRouter*>(this->sender());
+                disconnect(router, &UPnP::UPnPRouter::forwardComplete, this, &TransferRecv::sendReverseAck);
 
                 if (error)
                 {
@@ -603,18 +594,18 @@ namespace Konversation
 
         void TransferRecv::requestResume()
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
             setStatus(WaitingRemote, i18n("Waiting for remote host's acceptance"));
 
             startConnectionTimer(30);
 
-            qDebug() << "Requesting resume for " << m_partnerNick << " file " << m_fileName << " partner " << m_partnerPort;
+            qCDebug(KONVERSATION_LOG) << "Requesting resume for " << m_partnerNick << " file " << m_fileName << " partner " << m_partnerPort;
 
             Server *server = Application::instance()->getConnectionManager()->getServerByConnectionId(m_connectionId);
             if (!server)
             {
-                qDebug() << "Could not retrieve the instance of Server. Connection id: " << m_connectionId;
+                qCDebug(KONVERSATION_LOG) << "Could not retrieve the instance of Server. Connection id: " << m_connectionId;
                 failed(i18n("Could not send DCC RECV resume request to the partner via the IRC server."));
                 return;
             }
@@ -632,15 +623,14 @@ namespace Konversation
                                                           // public slot
         void TransferRecv::startResume(quint64 position)
         {
-            qDebug() << "Position:" << position;
+            qCDebug(KONVERSATION_LOG) << "Position:" << position;
 
             stopConnectionTimer();
 
             if ((quint64)m_transferringPosition != position)
             {
-                qDebug() << "remote responded with an unexpected position"<< endl
-                    << "expected: " << m_transferringPosition << endl
-                    << "remote response: " << position;
+                qCDebug(KONVERSATION_LOG) << "remote responded with an unexpected position\n"
+                    << "expected: " << m_transferringPosition << "\nremote response: " << position;
                 failed(i18n("Unexpected response from remote host"));
                 return;
             }
@@ -650,7 +640,7 @@ namespace Konversation
 
         void TransferRecv::connectToSendServer()
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
             // connect to sender
 
@@ -661,9 +651,13 @@ namespace Konversation
             m_recvSocket = new QTcpSocket(this);
 
             connect(m_recvSocket, &QTcpSocket::connected, this, &TransferRecv::startReceiving);
-            connect(m_recvSocket, static_cast<void (QTcpSocket::*)(QAbstractSocket::SocketError)>(&QTcpSocket::error), this, &TransferRecv::connectionFailed);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+            connect(m_recvSocket, &QTcpSocket::errorOccurred, this, &TransferRecv::connectionFailed);
+#else
+            connect(m_recvSocket, QOverload<QAbstractSocket::SocketError>::of(&QTcpSocket::error), this, &TransferRecv::connectionFailed);
+#endif
 
-            qDebug() << "Attempting to connect to " << m_partnerIp << ":" << m_partnerPort;
+            qCDebug(KONVERSATION_LOG) << "Attempting to connect to " << m_partnerIp << ":" << m_partnerPort;
 
             m_recvSocket->connectToHost(m_partnerIp, m_partnerPort);
         }
@@ -705,11 +699,15 @@ namespace Konversation
                 return;
             }
 
-            connect(m_recvSocket, static_cast<void (QTcpSocket::*)(QAbstractSocket::SocketError)>(&QTcpSocket::error), this, &TransferRecv::connectionFailed);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+            connect(m_recvSocket, &QTcpSocket::errorOccurred, this, &TransferRecv::connectionFailed);
+#else
+            connect(m_recvSocket, QOverload<QAbstractSocket::SocketError>::of(&QTcpSocket::error), this, &TransferRecv::connectionFailed);
+#endif
 
             // we don't need ServerSocket anymore
             m_serverSocket->close();
-            m_serverSocket = 0; // Will be deleted by parent
+            m_serverSocket = nullptr; // Will be deleted by parent
 
             if (Preferences::self()->dccUPnP())
             {
@@ -725,7 +723,7 @@ namespace Konversation
 
         void TransferRecv::startReceiving()
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             stopConnectionTimer();
 
             connect(m_recvSocket, &QTcpSocket::readyRead, this, &TransferRecv::readData);
@@ -745,13 +743,13 @@ namespace Konversation
                                                           // slot
         void TransferRecv::connectionFailed(QAbstractSocket::SocketError errorCode)
         {
-            qDebug() << "Code = " << errorCode << ", string = " << m_recvSocket->errorString();
+            qCDebug(KONVERSATION_LOG) << "Code = " << errorCode << ", string = " << m_recvSocket->errorString();
             failed(m_recvSocket->errorString());
         }
 
         void TransferRecv::readData()                  // slot
         {
-            //qDebug();
+            //qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             qint64 actual = m_recvSocket->read(m_buffer, m_bufferSize);
             if (actual > 0)
             {
@@ -773,32 +771,32 @@ namespace Konversation
 
         void TransferRecv::sendAck()                   // slot
         {
-            //qDebug() << m_transferringPosition << "/" << (KIO::fileoffset_t)m_fileSize;
+            //qCDebug(KONVERSATION_LOG) << m_transferringPosition << "/" << (KIO::fileoffset_t)m_fileSize;
 
             //It is bound to be 32bit according to dcc specs, -> 4GB limit.
             //But luckily no client ever reads this value,
             //except for old mIRC versions, but they couldn't send or receive files over 4GB anyway.
             //Note: The resume and filesize are set via dcc send command and can be over 4GB
 
-            quint32 pos = htonl((quint32)m_transferringPosition);
+            quint32 pos = htonl(static_cast<quint32>(m_transferringPosition));
 
             m_recvSocket->write((char*)&pos, 4);
-            if (m_transferringPosition == (KIO::fileoffset_t)m_fileSize)
+            if (m_transferringPosition == static_cast<KIO::fileoffset_t>(m_fileSize))
             {
-                qDebug() << "Sent final ACK.";
-                disconnect(m_recvSocket, 0, 0, 0);
+                qCDebug(KONVERSATION_LOG) << "Sent final ACK.";
+                disconnect(m_recvSocket, nullptr, nullptr, nullptr);
                 m_writeCacheHandler->close();             // WriteCacheHandler will send the signal done()
             }
-            else if (m_transferringPosition > (KIO::fileoffset_t)m_fileSize)
+            else if (m_transferringPosition > static_cast<KIO::fileoffset_t>(m_fileSize))
             {
-                qDebug() << "The remote host sent larger data than expected: " << m_transferringPosition;
+                qCDebug(KONVERSATION_LOG) << "The remote host sent larger data than expected: " << m_transferringPosition;
                 failed(i18n("Transfer error"));
             }
         }
 
         void TransferRecv::slotLocalWriteDone()        // <-WriteCacheHandler::done()
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             cleanUp();
             setStatus(Done);
             emit done(this);
@@ -807,13 +805,13 @@ namespace Konversation
                                                           // <- WriteCacheHandler::gotError()
         void TransferRecv::slotLocalGotWriteError(const QString &errorString)
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             failed(i18n("KIO error: %1", errorString));
         }
 
         void TransferRecv::startConnectionTimer(int secs)
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             m_connectionTimer->start(secs * 1000);
         }
 
@@ -822,13 +820,13 @@ namespace Konversation
             if (m_connectionTimer->isActive())
             {
                 m_connectionTimer->stop();
-                qDebug();
+                qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             }
         }
 
         void TransferRecv::connectionTimeout()         // slot
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             failed(i18n("Timed out"));
         }
 
@@ -838,7 +836,7 @@ namespace Konversation
             : m_transferJob(transferJob)
         {
             m_writeReady = true;
-            m_cacheStream = 0;
+            m_cacheStream = nullptr;
 
             connect(m_transferJob, &KIO::TransferJob::dataReq, this, &TransferRecvWriteCacheHandler::slotKIODataReq);
             connect(m_transferJob, &KIO::TransferJob::result, this, &TransferRecvWriteCacheHandler::slotKIOResult);
@@ -887,7 +885,7 @@ namespace Konversation
             m_writeReady = false;
 
             m_transferJob->sendAsyncData(m_cacheList.front());
-            //qDebug() << "wrote " << m_cacheList.front().size() << " bytes.";
+            //qCDebug(KONVERSATION_LOG) << "wrote " << m_cacheList.front().size() << " bytes.";
             m_cacheList.pop_front();
 
             return true;
@@ -895,11 +893,11 @@ namespace Konversation
 
         void TransferRecvWriteCacheHandler::close()    // public
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             write(true);                                // write once if kio is ready to write
             m_transferJob->setAsyncDataEnabled(m_writeAsyncMode = false);
-            qDebug() << "switched to synchronized mode.";
-            qDebug() << "flushing... (remaining caches: " << m_cacheList.count() << ")";
+            qCDebug(KONVERSATION_LOG) << "switched to synchronized mode.";
+            qCDebug(KONVERSATION_LOG) << "flushing... (remaining caches: " << m_cacheList.count() << ")";
         }
 
         void TransferRecvWriteCacheHandler::closeNow() // public
@@ -908,16 +906,16 @@ namespace Konversation
             if (m_transferJob)
             {
                 m_transferJob->kill();
-                m_transferJob = 0;
+                m_transferJob = nullptr;
             }
             m_cacheList.clear();
             delete m_cacheStream;
-            m_cacheStream = 0;
+            m_cacheStream = nullptr;
         }
 
         void TransferRecvWriteCacheHandler::slotKIODataReq(KIO::Job *job, QByteArray &data)
         {
-            Q_UNUSED(job);
+            Q_UNUSED(job)
 
             // We are in writeAsyncMode if there is more data to be read in from dcc
             if (m_writeAsyncMode)
@@ -932,14 +930,14 @@ namespace Konversation
                     // once we write everything in cache, the file is complete.
                     // This function will be called once more after this last data is written.
                     data = m_cacheList.front();
-                    qDebug() << "will write " << m_cacheList.front().size() << " bytes.";
+                    qCDebug(KONVERSATION_LOG) << "will write " << m_cacheList.front().size() << " bytes.";
                     m_cacheList.pop_front();
                 }
                 else
                 {
                     // finally, no data left to write or read.
-                    qDebug() << "flushing done.";
-                    m_transferJob = 0;
+                    qCDebug(KONVERSATION_LOG) << "flushing done.";
+                    m_transferJob = nullptr;
                     emit done();                          // -> TransferRecv::slotLocalWriteDone()
                 }
             }
@@ -949,8 +947,8 @@ namespace Konversation
         {
             Q_ASSERT(m_transferJob);
 
-            disconnect(m_transferJob, 0, 0, 0);
-            m_transferJob = 0;
+            disconnect(m_transferJob, nullptr, nullptr, nullptr);
+            m_transferJob = nullptr;
 
             if (job->error())
             {
